"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertWorkspaceDefinition = void 0;
const path_1 = __importDefault(require("path"));
function convertWorkspaceDefinition({ definition, absolutePathToDefinition, }) {
    const absolutePathToWorkspaceDir = path_1.default.dirname(absolutePathToDefinition);
    return {
        _absolutePath: absolutePathToWorkspaceDir,
        name: definition.name,
        absolutePathToInput: path_1.default.resolve(absolutePathToWorkspaceDir, getDefinitionLocation(definition)),
        plugins: getGenerators(definition).map((plugin) => ({
            name: plugin.name,
            version: plugin.version,
            absolutePathToOutput: plugin.output != null ? path_1.default.resolve(absolutePathToWorkspaceDir, plugin.output) : undefined,
            config: plugin.config,
            helpers: plugin.helpers != null
                ? plugin.helpers.map((helper) => ({
                    name: helper.name,
                    version: helper.version,
                    absoluteLocationOnDisk: helper.locationOnDisk != null
                        ? path_1.default.resolve(absolutePathToWorkspaceDir, helper.locationOnDisk)
                        : undefined,
                }))
                : [],
        })),
    };
}
exports.convertWorkspaceDefinition = convertWorkspaceDefinition;
function getDefinitionLocation(definition) {
    if (definition.definition != null) {
        return definition.definition;
    }
    else if (definition.input != null) {
        return definition.input;
    }
    else {
        throw new Error(".fernrc.yml is missing definition");
    }
}
function getGenerators(definition) {
    if (definition.generators != null) {
        return definition.generators;
    }
    else if (definition.plugins != null) {
        return definition.plugins;
    }
    else {
        throw new Error(".fernrc.yml is missing generators");
    }
}
